@@ -1,25 +1,25 @@
 #!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #******************************************************************************
-# 
+#
 #  Project:  GDAL
 #  Purpose:  Command line raster calculator with numpy syntax
 #  Author:   Chris Yesson, chris.yesson@ioz.ac.uk
-# 
+#
 #******************************************************************************
 #  Copyright (c) 2010, Chris Yesson <chris.yesson@ioz.ac.uk>
 #  Copyright (c) 2010-2011, Even Rouault <even dot rouault at mines-paris dot org>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -42,13 +42,15 @@
 # gdal_calc.py -A input.tif --outfile=result.tif --calc="A*(A>0)" --NoDataValue=0
 ################################################################
 
-from osgeo import gdal
-from osgeo import gdalnumeric
+from optparse import OptionParser
+import os
+import sys
+
 import numpy
 
-from optparse import OptionParser
-import sys
-import os
+from osgeo import gdal
+from osgeo import gdalnumeric
+
 
 # create alphabetic list for storing input layers
 AlphaList=["A","B","C","D","E","F","G","H","I","J","K","L","M",
@@ -65,6 +67,10 @@ def doit(opts, args):
     if opts.debug:
         print("gdal_calc.py starting calculation %s" %(opts.calc))
 
+    # set up global namespace for eval with all functions of gdalnumeric
+    global_namespace = dict([(key, getattr(gdalnumeric, key))
+        for key in dir(gdalnumeric) if not key.startswith('__')])
+
     ################################################################
     # fetch details of input layers
     ################################################################
@@ -177,7 +183,7 @@ def doit(opts, args):
         print("output file: %s, dimensions: %s, %s, type: %s" %(opts.outF,myOut.RasterXSize,myOut.RasterYSize,myOutType))
 
     ################################################################
-    # find block size to chop grids into bite-sized chunks 
+    # find block size to chop grids into bite-sized chunks
     ################################################################
 
     # use the block size of the first layer to read efficiently
@@ -197,7 +203,7 @@ def doit(opts, args):
     ProgressCt=-1
     ProgressMk=-1
     ProgressEnd=nXBlocks*nYBlocks*allBandsCount
-    
+
     ################################################################
     # start looping through each band in allBandsCount
     ################################################################
@@ -247,6 +253,9 @@ def doit(opts, args):
                 myNDVs=numpy.zeros(myBufSize)
                 myNDVs.shape=(nYValid,nXValid)
 
+                # modules available to calculation
+                local_namespace = {}
+
                 # fetch data for each input layer
                 for i,Alpha in enumerate(myAlphaList):
 
@@ -262,20 +271,20 @@ def doit(opts, args):
                     # fill in nodata values
                     myNDVs=1*numpy.logical_or(myNDVs==1, myval==myNDV[i])
 
-                    # create an array of values for this block
-                    exec("%s=myval" %Alpha)
+                    # add an array of values for this block to the eval namespace
+                    local_namespace[Alpha] = myval
                     myval=None
 
 
                 # try the calculation on the array blocks
                 try:
-                    myResult = eval(opts.calc)
+                    myResult = eval(opts.calc, global_namespace, local_namespace)
                 except:
                     print("evaluation of calculation %s failed" %(opts.calc))
                     raise
 
-                # propogate nodata values 
-                # (set nodata cells to zero then add nodata value to these cells)
+                # Propagate nodata values (set nodata cells to zero
+                # then add nodata value to these cells).
                 myResult = ((1*(myNDVs==0))*myResult) + (myOutNDV*myNDVs)
 
                 # write data block to the output file
