@@ -1,26 +1,26 @@
 #!/usr/local/bin/python2.7
 # -*- coding: utf-8 -*-
 #******************************************************************************
-#  $Id: gdal_polygonize.py 28389 2015-01-30 19:26:09Z rouault $
-# 
+#  $Id: gdal_polygonize.py 33790 2016-03-26 12:42:12Z goatbar $
+#
 #  Project:  GDAL Python Interface
 #  Purpose:  Application for converting raster data to a vector polygon layer.
 #  Author:   Frank Warmerdam, warmerdam@pobox.com
-# 
+#
 #******************************************************************************
 #  Copyright (c) 2008, Frank Warmerdam
 #  Copyright (c) 2009-2013, Even Rouault <even dot rouault at mines-paris dot org>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -30,13 +30,13 @@
 #  DEALINGS IN THE SOFTWARE.
 #******************************************************************************
 
-try:
-    from osgeo import gdal, ogr, osr
-except ImportError:
-    import gdal, ogr, osr
-
 import sys
 
+from osgeo import gdal
+from osgeo import ogr
+from osgeo import osr
+
+
 def Usage():
     print("""
 gdal_polygonize [-8] [-nomask] [-mask filename] raster_file [-b band]
@@ -80,14 +80,14 @@ while i < len(argv):
 
     elif arg == '-8':
         options.append('8CONNECTED=8')
-        
+
     elif arg == '-nomask':
         mask = 'none'
-        
+
     elif arg == '-mask':
         i = i + 1
         mask = argv[i]
-        
+
     elif arg == '-b':
         i = i + 1
         src_band_n = int(argv[i])
@@ -114,7 +114,7 @@ if src_filename is None or dst_filename is None:
 
 if dst_layername is None:
     dst_layername = 'out'
-    
+
 # =============================================================================
 # 	Verify we have next gen bindings with the polygonize method.
 # =============================================================================
@@ -132,7 +132,7 @@ except:
 # =============================================================================
 
 src_ds = gdal.Open( src_filename )
-    
+
 if src_ds is None:
     print('Unable to open %s' % src_filename)
     sys.exit(1)
@@ -181,12 +181,12 @@ if dst_layer is None:
     if src_ds.GetProjectionRef() != '':
         srs = osr.SpatialReference()
         srs.ImportFromWkt( src_ds.GetProjectionRef() )
-        
+
     dst_layer = dst_ds.CreateLayer(dst_layername, srs = srs )
 
     if dst_fieldname is None:
         dst_fieldname = 'DN'
-        
+
     fd = ogr.FieldDefn( dst_fieldname, ogr.OFTInteger )
     dst_layer.CreateField( fd )
     dst_field = 0
@@ -204,18 +204,11 @@ if quiet_flag:
     prog_func = None
 else:
     prog_func = gdal.TermProgress
-    
+
 result = gdal.Polygonize( srcband, maskband, dst_layer, dst_field, options,
                           callback = prog_func )
-    
+
 srcband = None
 src_ds = None
 dst_ds = None
 mask_ds = None
-
-
-
-
-
-
-
