@@ -1,6 +1,6 @@
 #!/usr/local/bin/python2.7
 ###############################################################################
-#  $Id: gdal_retile.py 28389 2015-01-30 19:26:09Z rouault $
+#  $Id: gdal_retile.py 33790 2016-03-26 12:42:12Z goatbar $
 #
 # Purpose:  Module for retiling (merging) tiles and building tiled pyramids
 # Author:   Christian Meuller, christian.mueller@nvoe.at
@@ -29,19 +29,13 @@
 # DEALINGS IN THE SOFTWARE.
 ###############################################################################
 
-
-try:
-    from osgeo import gdal
-    from osgeo import ogr
-    from osgeo import osr
-except:
-    import gdal
-    import ogr
-    import osr
-
-import sys
-import os
 import math
+import os
+import sys
+
+from osgeo import gdal
+from osgeo import ogr
+from osgeo import osr
 
 try:
     progress = gdal.TermProgress_nocb
@@ -264,16 +258,16 @@ class mosaic_info:
             assert tw_yoff >= 0
             assert sw_xoff >= 0
             assert sw_yoff >= 0
-            
+
             for bandNr in range(1, self.bands + 1):
                 s_band = sourceDS.GetRasterBand( bandNr )
                 t_band = resultDS.GetRasterBand( bandNr )
                 if self.ct is not None:
                     t_band.SetRasterColorTable(self.ct)
                 t_band.SetRasterColorInterpretation(self.ci[bandNr-1])
-                
+
                 data = s_band.ReadRaster( sw_xoff, sw_yoff, sw_xsize, sw_ysize, tw_xsize, tw_ysize, self.band_type )
-                if data is None:                    
+                if data is None:
                     print(gdal.GetLastErrorMsg())
 
                 t_band.WriteRaster(tw_xoff, tw_yoff, tw_xsize, tw_ysize, data )
@@ -867,7 +861,7 @@ def main(args = None):
         elif arg == '-useDirForEachRow':
             UseDirForEachRow=True
         elif arg[:1] == '-':
-            print('Unrecognised command option: %s' % arg)
+            print('Unrecognized command option: %s' % arg)
             Usage()
             return 1
 
